import { OT, pipe, T } from '@contentlayer/utils/effect';
export const provideNestedTypeDefMap = () => pipe(T.succeed({
    body: {
        _tag: 'NestedTypeDef',
        name: 'Body',
        description: 'The body generated using page content',
        fieldDefs: [
            {
                name: 'html',
                type: 'string',
                description: 'The HTML body',
                isSystemField: false,
                default: undefined,
                isRequired: true,
            },
        ],
        extensions: {},
    },
    dateRange: {
        _tag: 'NestedTypeDef',
        name: 'DateRange',
        description: 'Nested type definition for Notion date properties',
        fieldDefs: [
            {
                name: 'start',
                type: 'date',
                description: undefined,
                isSystemField: false,
                default: undefined,
                isRequired: true,
            },
            {
                name: 'end',
                type: 'date',
                description: undefined,
                isSystemField: false,
                default: undefined,
                isRequired: false,
            },
            {
                name: 'timezone',
                type: 'string',
                description: undefined,
                isSystemField: false,
                default: undefined,
                isRequired: false,
            },
        ],
        extensions: {},
    },
    user: {
        _tag: 'NestedTypeDef',
        name: 'User',
        description: 'Nested type definition for Notion people properties',
        fieldDefs: [
            {
                name: 'type',
                type: 'enum',
                options: ['person', 'bot'],
                description: 'The user type',
                isSystemField: false,
                default: undefined,
                isRequired: false,
            },
            {
                name: 'name',
                type: 'string',
                description: 'The user name',
                isSystemField: false,
                default: undefined,
                isRequired: false,
            },
            {
                name: 'avatarUrl',
                type: 'string',
                description: 'The user avatar',
                isSystemField: false,
                default: undefined,
                isRequired: false,
            },
            {
                name: 'email',
                type: 'string',
                description: 'User email address, only if the user is a person and the integration has user capabilities to access email addresses.',
                isSystemField: false,
                default: undefined,
                isRequired: false,
            },
            {
                name: 'workspace',
                type: 'string',
                description: 'User workspace owner, only if the user is a bot',
                isSystemField: false,
                default: undefined,
                isRequired: false,
            },
        ],
        extensions: {},
    },
}), OT.withSpan('@contentlayer/source-notion/schema:provideNestedTypeDefMap'));
//# sourceMappingURL=provideNestedTypeDefMap.js.map